@@ -4,7 +4,6 @@ use std::str::FromStr;
 
 use bzip2::read::BzDecoder;
 use flate2::read::GzDecoder;
-use xz::read::XzDecoder;
 use zip::ZipArchive;
 
 use crate::{Error, Metadata};
@@ -23,10 +22,8 @@ pub enum DistributionType {
 #[derive(Debug, Clone, Copy)]
 enum SDistType {
     Zip,
-    Tar,
     GzTar,
     BzTar,
-    XzTar,
 }
 
 /// Python package distribution
@@ -34,6 +31,7 @@ enum SDistType {
 pub struct Distribution {
     dist_type: DistributionType,
     metadata: Metadata,
+    python_version: String,
 }
 
 impl FromStr for SDistType {
@@ -42,10 +40,8 @@ impl FromStr for SDistType {
     fn from_str(s: &str) -> Result<Self, Self::Err> {
         let dist_type = match s {
             "zip" => SDistType::Zip,
-            "tar" => SDistType::Tar,
             "gz" => SDistType::GzTar,
             "bz2" => SDistType::BzTar,
-            "xz" => SDistType::XzTar,
             _ => return Err(Error::UnknownDistributionType),
         };
         Ok(dist_type)
@@ -58,22 +54,49 @@ impl Distribution {
         let path = path.as_ref();
         if let Some(ext) = path.extension().and_then(|ext| ext.to_str()) {
             let dist_type = match ext {
-                "zip" | "tar" | "gz" | "bz2" | "xz" => DistributionType::SDist,
+                "zip" | "gz" | "bz2" => DistributionType::SDist,
                 "egg" => DistributionType::Egg,
                 "whl" => DistributionType::Wheel,
                 _ => return Err(Error::UnknownDistributionType),
             };
-            let metadata = match dist_type {
+            let (metadata, python_version) = match dist_type {
                 DistributionType::SDist => {
                     let sdist_type: SDistType = ext.parse()?;
-                    Self::parse_sdist(path, sdist_type)
+                    (Self::parse_sdist(path, sdist_type)?, "source".to_string())
                 }
-                DistributionType::Egg => Self::parse_egg(path),
-                DistributionType::Wheel => Self::parse_wheel(path),
-            }?;
+                DistributionType::Egg => {
+                    let parts: Vec<&str> = path
+                        .file_stem()
+                        .unwrap()
+                        .to_str()
+                        .unwrap()
+                        .split('-')
+                        .collect();
+                    let python_version = match parts.as_slice() {
+                        [_name, _version, py_ver] => py_ver,
+                        _ => "any",
+                    };
+                    (Self::parse_egg(path)?, python_version.to_string())
+                }
+                DistributionType::Wheel => {
+                    let parts: Vec<&str> = path
+                        .file_stem()
+                        .unwrap()
+                        .to_str()
+                        .unwrap()
+                        .split('-')
+                        .collect();
+                    let python_version = match parts.as_slice() {
+                        [_name, _version, py_ver, _abi_tag, _plat_tag] => py_ver,
+                        _ => "any",
+                    };
+                    (Self::parse_wheel(path)?, python_version.to_string())
+                }
+            };
             return Ok(Self {
                 dist_type,
                 metadata,
+                python_version,
             });
         }
         Err(Error::UnknownDistributionType)
@@ -89,19 +112,22 @@ impl Distribution {
         &self.metadata
     }
 
+    /// Returns the supported Python version tag
+    ///
+    /// For source distributions the version tag is always `source`
+    pub fn python_version(&self) -> &str {
+        &self.python_version
+    }
+
     fn parse_sdist(path: &Path, sdist_type: SDistType) -> Result<Metadata, Error> {
         match sdist_type {
             SDistType::Zip => Self::parse_zip(path, "PKG-INFO"),
             SDistType::GzTar => {
                 Self::parse_tar(GzDecoder::new(BufReader::new(fs_err::File::open(path)?)))
             }
-            SDistType::Tar => Self::parse_tar(BufReader::new(fs_err::File::open(path)?)),
             SDistType::BzTar => {
                 Self::parse_tar(BzDecoder::new(BufReader::new(fs_err::File::open(path)?)))
             }
-            SDistType::XzTar => {
-                Self::parse_tar(XzDecoder::new(BufReader::new(fs_err::File::open(path)?)))
-            }
         }
     }
 
